@@ -1,6 +1,10 @@
 import asyncio
 import atexit
 from typing import List, NoReturn, Optional, Tuple, Union
+
+from graia.broadcast.entities.inject_rule import SpecialEventType
+
+from graia.application.event import MiraiEvent
 from .logger import AbstractLogger, LoggingLogger
 from .entities import MiraiConfig
 
@@ -33,20 +37,24 @@ class GraiaMiraiApplication:
     session: ClientSession
     connect_info: Session
     logger: AbstractLogger
+    debug: bool
 
     def __init__(self, *,
         broadcast: Broadcast,
         connect_info: Session,
         session: Optional[ClientSession] = None,
-        logger: Optional[AbstractLogger] = None
+        logger: Optional[AbstractLogger] = None,
+        debug: bool = False
     ):
         self.broadcast = broadcast
         self.connect_info = connect_info
         self.session = session or ClientSession(loop=broadcast.loop)
         self.logger = logger or LoggingLogger()
-        self.broadcast.getDefaultNamespace().injected_dispatchers.append(
-            AppMiddlewareAsDispatcher(self)
+
+        self.broadcast.addInjectionRule(
+            SpecialEventType(MiraiEvent, AppMiddlewareAsDispatcher(self))
         )
+        self.debug = debug
 
     def url_gen(self, path) -> str:
         return str(URL(str(self.connect_info.host)).parent / path)
@@ -252,13 +260,14 @@ class GraiaMiraiApplication:
             raise_for_return_code(data)
             
             result = []
-            for i in data['data']:
-                if i['type'] == "GroupMessage":
-                    result.append(GroupMessage.parse_obj(i))
-                elif i['type'] == "FriendMessage":
-                    result.append(FriendMessage.parse_obj(i))
-                elif i['type'] == "TempMessage":
-                    result.append(TempMessage.parse_obj(i))
+            for event in data:
+                if self.debug:
+                    self.logger.debug("http polling received: " + str(event))
+                try:
+                    result.append(await self.auto_parse_by_type(event))
+                except ValueError:
+                    self.logger.error("".join(["received a unknown event: ", event.get("type"), str(event)]))
+                    continue
             return result
     
     @requireAuthenticated
@@ -515,10 +524,11 @@ class GraiaMiraiApplication:
             while True:
                 try:
                     received_data = await connection.receive_json()
-                    #print("d", received_data)
                 except TypeError:
                     continue
                 if received_data:
+                    if self.debug:
+                        self.logger.debug("websocket received: " + str(received_data))
                     try:
                         event = await self.auto_parse_by_type(received_data)
                     except ValueError as e:
@@ -551,7 +561,7 @@ class GraiaMiraiApplication:
         fetch_method = self.http_fetchmessage_poster if not self.connect_info.websocket else self.ws_all_poster
         config: MiraiConfig = await self.getConfig()
         if not self.connect_info.websocket: # 不启用 websocket
-            self.logger.info("using websocket to receive event")
+            self.logger.info("using http to receive event")
             if config.enableWebsocket: # 配置中已经启用
                 await self.modifyConfig(enableWebsocket=False)
         else: # 启用ws
